pub struct StreamRefProtocolMessageCounts {
pub cumulative_demand: u64,
pub sequenced_on_next: u64,
pub ack: u64,
}Expand description
Counts selected StreamRefs protocol messages successfully written by a carrier endpoint.
Fields
cumulative_demand: u64sequenced_on_next: u64ack: u64Trait Implementations
Sourceimpl Clone for StreamRefProtocolMessageCounts
impl Clone for StreamRefProtocolMessageCounts
Sourcefn clone(&self) -> StreamRefProtocolMessageCounts
fn clone(&self) -> StreamRefProtocolMessageCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StreamRefProtocolMessageCounts
Sourceimpl Default for StreamRefProtocolMessageCounts
impl Default for StreamRefProtocolMessageCounts
Sourcefn default() -> StreamRefProtocolMessageCounts
fn default() -> StreamRefProtocolMessageCounts
Returns the “default value” for a type. Read more
impl Eq for StreamRefProtocolMessageCounts
Sourceimpl PartialEq for StreamRefProtocolMessageCounts
impl PartialEq for StreamRefProtocolMessageCounts
Sourcefn eq(&self, other: &StreamRefProtocolMessageCounts) -> bool
fn eq(&self, other: &StreamRefProtocolMessageCounts) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StreamRefProtocolMessageCounts