TlsByteSink

Type Alias TlsByteSink 

pub type TlsByteSink = Sink<Vec<u8>, StreamCompletion<NotUsed>>;
TLS byte sink used by accepted and outgoing TLS connections.

The sink writes one upstream chunk at a time and sends TLS/TCP shutdown from its resource close hook when upstream completes.

Aliased Type

pub struct TlsByteSink { /* private fields */ }