pub trait ConnectionLifecycleExt<Mat> {
// Required method
fn graceful_shutdown_on_upstream_finish(self) -> Self;
// Provided method
fn half_close_on_upstream_finish(self) -> Self
where Self: Sized { ... }
}Expand description
Extension methods for connection byte flows.
Required Methods
Sourcefn graceful_shutdown_on_upstream_finish(self) -> Self
fn graceful_shutdown_on_upstream_finish(self) -> Self
Makes the half-close behavior explicit at the call site.
Completing the upstream side of Datum TCP/TLS connection flows shuts down the write direction and keeps the read direction alive. The method returns the original flow because the transport sink already performs the shutdown.
Provided Methods
Sourcefn half_close_on_upstream_finish(self) -> Selfwhere
Self: Sized,
fn half_close_on_upstream_finish(self) -> Selfwhere
Self: Sized,
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".